==> gcore_interface_sdk-0.13-py3-none-any.whl: gc_sdk/methods.py <==
""" Модуль содержит все методы SDK для взаимодействия с API """

methods_dict = {'open_external_gate': {'command': 'operate_gate_manual_control',
                                       'args': (),
                                       'kwargs': {'operation': 'open', 'gate_name': 'entry'},
                                       'test': True,
                                       'description': 'Открыть внешние ворота'},
                'open_internal_gate': {'command': 'operate_gate_manual_control',
                                       'args': (),
                                       'kwargs': {'operation': 'open', 'gate_name': 'exit'},
                                       'test': True,
                                       'description': 'Открыть внутренние ворота'},
                'close_external_gate': {'command': 'operate_gate_manual_control',
                                        'args': (),
                                        'kwargs': {'operation': 'close', 'gate_name': 'entry'},
                                        'test': True,
                                        'description': 'Закрыть внешние ворота'},
                'close_internal_gate': {'command': 'operate_gate_manual_control',
                                        'args': (),
                                        'kwargs': {'operation': 'close', 'gate_name': 'exit'},
                                        'test': True,
                                        'description': 'Закрыть внутренние ворота'},
                'get_status': {'command': 'get_status',
                               'args': (),
                               'kwargs': {},
                               'test': True,
                               'description': 'Получить статус GCore'},
                'start_weight_round': {'command': 'start_weight_round',
                                       'args': (),
                                       'kwargs': {},
                                       'test': False,
                                       'description': 'Начать раунд взвешивания'},
                'change_opened_record': {'command': 'change_opened_record',
                                         'args': (),
                                         'kwargs': {},
                                         'test': False,
                                         'description': 'Изменить запись, у которого еще только брутто'},
                'try_auth_user': {'command': 'try_auth_user',
                                  'args': (),
                                  'kwargs': {},
                                  'test': False,
                                  'description': 'Попытка авторизовать юзера'},
                'capture_cm_launched': {'command': 'capture_cm_launched',
                                        'args': (),
                                        'kwargs': {},
                                        'test': False,
                                        'description': 'Зафиксировать запуск клиентского приложения'},
                'capture_cm_terminated': {'command': 'capture_cm_terminated',
                                          'args': (),
                                          'kwargs': {},
                                          'test': False,
                                          'description': 'Зафиксировать отключение клиентского приложения'},
                'add_comment': {'command': 'add_comment',
                                'args': (),
                                'kwargs': {},
                                'test': False,
                                'description': 'Добавить комментарий к записи'},
                'close_opened_record': {'command': 'close_opened_record',
                                        'args': (),
                                        'kwargs': {},
                                        'test': False,
                                        'description': 'Закрывает запись у которого только раунд брутто (без тары)'},
                'get_unfinished_records': {'command': 'get_unfinished_records',
                                           'args': (),
                                           'kwargs': {},
                                           'test': False,
                                           'description': 'Получить все незавершенные записи (только раунд брутто)'},
                'get_health_monitor': {'command': 'get_health_monitor',
                                       'args': (),
                                       'kwargs': {},
                                       'test': False,
                                       'description': 'Получить информацию о состоянии GCore'}
                }

==> gcore_interface_sdk-0.131-py3-none-any.whl: gc_sdk/methods.py <==
""" Модуль содержит все методы SDK для взаимодействия с API """

methods_dict = {'open_external_gate': {'command': 'operate_gate_manual_control',
                                       'args': (),
                                       'kwargs': {'operation': 'open', 'gate_name': 'entry'},
                                       'test': False,
                                       'description': 'Открыть внешние ворота'},
                'open_internal_gate': {'command': 'operate_gate_manual_control',
                                       'args': (),
                                       'kwargs': {'operation': 'open', 'gate_name': 'exit'},
                                       'test': False,
                                       'description': 'Открыть внутренние ворота'},
                'close_external_gate': {'command': 'operate_gate_manual_control',
                                        'args': (),
                                        'kwargs': {'operation': 'close', 'gate_name': 'entry'},
                                        'test': False,
                                        'description': 'Закрыть внешние ворота'},
                'close_internal_gate': {'command': 'operate_gate_manual_control',
                                        'args': (),
                                        'kwargs': {'operation': 'close', 'gate_name': 'exit'},
                                        'test': False,
                                        'description': 'Закрыть внутренние ворота'},
                'get_status': {'command': 'get_status',
                               'args': (),
                               'kwargs': {},
                               'test': True,
                               'description': 'Получить статус GCore'},
                'start_weight_round': {'command': 'start_weight_round',
                                       'args': (),
                                       'kwargs': {},
                                       'test': False,
                                       'description': 'Начать раунд взвешивания'},
                'change_opened_record': {'command': 'change_opened_record',
                                         'args': (),
                                         'kwargs': {},
                                         'test': False,
                                         'description': 'Изменить запись, у которого еще только брутто'},
                'try_auth_user': {'command': 'try_auth_user',
                                  'args': (),
                                  'kwargs': {},
                                  'test': False,
                                  'description': 'Попытка авторизовать юзера'},
                'capture_cm_launched': {'command': 'capture_cm_launched',
                                        'args': (),
                                        'kwargs': {},
                                        'test': False,
                                        'description': 'Зафиксировать запуск клиентского приложения'},
                'capture_cm_terminated': {'command': 'capture_cm_terminated',
                                          'args': (),
                                          'kwargs': {},
                                          'test': False,
                                          'description': 'Зафиксировать отключение клиентского приложения'},
                'add_comment': {'command': 'add_comment',
                                'args': (),
                                'kwargs': {},
                                'test': False,
                                'description': 'Добавить комментарий к записи'},
                'close_opened_record': {'command': 'close_opened_record',
                                        'args': (),
                                        'kwargs': {},
                                        'test': False,
                                        'description': 'Закрывает запись у которого только раунд брутто (без тары)'},
                'get_unfinished_records': {'command': 'get_unfinished_records',
                                           'args': (),
                                           'kwargs': {},
                                           'test': False,
                                           'description': 'Получить все незавершенные записи (только раунд брутто)'},
                'get_health_monitor': {'command': 'get_health_monitor',
                                       'args': (),
                                       'kwargs': {},
                                       'test': False,
                                       'description': 'Получить информацию о состоянии GCore'},
                'get_history': {'command': 'get_history',
                                'args': (),
                                'kwargs': {},
                                'test': True}
                }
